/**
 * Copyright (C) 2011 Agrosense <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.isobus.type;

import java.util.List;
import nl.cloudfarming.client.isobus.model.DataLogValue;
import nl.cloudfarming.client.isobus.model.IsobusTime;
import nl.cloudfarming.client.isobus.model.Position;
import org.openide.nodes.ChildFactory;
import org.openide.nodes.Children;
import org.openide.nodes.Node;
import org.openide.util.NbBundle;
import org.openide.util.NbBundle.Messages;

/**
 *
 * @author Gerben Feenstra
 */
@Messages({
    "isobus.project.taskdata.node.name.datalogvalue=DatalogValue ({0})",
    "isobus.project.taskdata.node.name.position=Position ({0}, {1})"
})
public class TimeChildFactory extends ChildFactory<Node> {

    private static final String POSITION_NODE_ICON = "";
    private static final String DATALOGVALUE_NODE_ICON = "";
    private final IsobusTime time;

    public TimeChildFactory(IsobusTime time) {
        this.time = time;
    }

    @Override
    protected boolean createKeys(List<Node> toPopulate) {

        // Position (PTN)
        Position position = time.getPTN();
        if (position != null) {
            String displayName = NbBundle.getMessage(TimeChildFactory.class, "isobus.project.taskdata.node.name.position", position.getPositionEast(), position.getPositionNorth());
            toPopulate.add(new IsobusCommonNode(Children.LEAF, position, POSITION_NODE_ICON, displayName));
        }

        // DataLogValue (DLV)
        for (DataLogValue dataLogValue : time.getDLV()) {
            String displayName = NbBundle.getMessage(TimeChildFactory.class, "isobus.project.taskdata.node.name.datalogvalue", dataLogValue.getProcessDataValue());
            toPopulate.add(new IsobusCommonNode(Children.LEAF, dataLogValue, DATALOGVALUE_NODE_ICON, displayName));
        }
        return true;
    }

    @Override
    protected Node createNodeForKey(Node node) {
        return node;
    }
}
